==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-runner/translations/razor-runner_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Razor-runner Settings</source>
        <translation>Ustawiania Razor runner</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Pozycja:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Pokazuj na:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="56"/>
        <source>Shortcut:</source>
        <translation>Skrót:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="68"/>
        <source>Top edge of screen</source>
        <translation>Góra ekarnu</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="69"/>
        <source>Center of screen</source>
        <translation>Środku ekranu</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="75"/>
        <source>Monitor where the mouse</source>
        <translation>Tam gdzie mysz</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="80"/>
        <source>Always on %1 monitor</source>
        <translation>Zawsze na %1 ekranie</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Komenda</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="86"/>
        <source>Configure razor-runner</source>
        <translation>Konfiguruj razor-runner</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="286"/>
        <source>Press &quot;%1&quot; to see dialog.</source>
        <translation>Naciśnij &quot;%1&quot; aby zobaczyć okno.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="219"/>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="305"/>
        <source>Mathematics</source>
        <translation>Matematyka</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-runner/translations/razor-runner_pl_PL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl_PL" version="2.0">
<context>
    <name>ConfigureDialog</name>
    <message>
        <source>Razor-runner Settings</source>
        <translation>Ustawienia Razor-runner</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <source>Positioning:</source>
        <translation>Pozycja:</translation>
    </message>
    <message>
        <source>Show on:</source>
        <translation>Pokasz na:</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Skrót:</translation>
    </message>
    <message>
        <source>Top edge of screen</source>
        <translation>Góra ekarnu</translation>
    </message>
    <message>
        <source>Center of screen</source>
        <translation>Środek ekranu</translation>
    </message>
    <message>
        <source>Monitor where the mouse</source>
        <translation>Tam gdzie mysz</translation>
    </message>
    <message>
        <source>Always on %1 monitor</source>
        <translation>Zawsze na %1 ekranie</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Application launcher </source>
        <translation>Komenda</translation>
    </message>
    <message>
        <source>Configure razor-runner</source>
        <translation>Konfiguruj razor-runner</translation>
    </message>
    <message>
        <source>Clear razor-runner History</source>
        <translation>Wyczyść Historię razor-runnera</translation>
    </message>
    <message>
        <source>Press &quot;%1&quot; to see dialog.</source>
        <translation>Naciśnij &quot;%1&quot; aby zobaczyć okno.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>Mathematics</source>
        <translation>Matematyka</translation>
    </message>
    <message>
        <source>Razor Power Management</source>
        <translation>Menadżer Zasilania Razor</translation>
    </message>
</context>
</TS>
